@@ -11,7 +11,7 @@ from SoftLayer.CLI import formatting
 from SoftLayer.CLI import helpers
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('identifier')
 @click.option('--memory', type=click.INT, help="Memory Size in GB")
 @click.option('--network', help="Network port speed in Mbps",
@@ -51,7 +51,7 @@ def cli(env, identifier, memory, network, drive_controller, public_bandwidth, ad
                 "This action will incur charges on your account. Continue?")):
             raise exceptions.CLIAbort('Aborted')
 
-    disk_list = list()
+    disk_list = []
     if add_disk:
         for guest_disk in add_disk:
             disks = {'description': 'add_disk', 'capacity': guest_disk[0], 'number': guest_disk[1]}
