@@ -17,6 +17,7 @@ from SoftLayer.CLI import exceptions
 from SoftLayer.fixtures import SoftLayer_Product_Order
 from SoftLayer import SoftLayerError
 from SoftLayer import testing
+from SoftLayer import utils
 
 
 class ServerCLITests(testing.TestCase):
@@ -397,8 +398,8 @@ class ServerCLITests(testing.TestCase):
                                    ])
 
         self.assert_no_fail(result)
-        self.assertEqual(json.loads(result.output),
-                         {'id': 98765, 'created': '2013-08-02 15:23:47'})
+        self.assertIn('Warning: Closed soon: TEST00.pod2', result.output)
+        self.assertIn('"id": 98765', result.output)
 
     @mock.patch('SoftLayer.CLI.template.export_to_template')
     def test_create_server_with_export(self, export_mock):
@@ -621,13 +622,13 @@ class ServerCLITests(testing.TestCase):
         mock.return_value = True
         result = self.run_command(['server', 'toggle-ipmi', '--enable', '12345'])
         self.assert_no_fail(result)
-        self.assertEqual(result.output, 'True\n')
+        self.assertEqual(result.output, 'true\n')
 
     def test_toggle_ipmi_off(self):
         mock.return_value = True
         result = self.run_command(['server', 'toggle-ipmi', '--disable', '12345'])
         self.assert_no_fail(result)
-        self.assertEqual(result.output, 'True\n')
+        self.assertEqual(result.output, 'true\n')
 
     def test_bandwidth_hw(self):
         if sys.version_info < (3, 6):
@@ -636,17 +637,17 @@ class ServerCLITests(testing.TestCase):
         self.assert_no_fail(result)
 
         date = '2019-05-20 23:00'
-        # number of characters from the end of output to break so json can parse properly
-        pivot = 157
         # only pyhon 3.7 supports the timezone format slapi uses
         if sys.version_info < (3, 7):
             date = '2019-05-20T23:00:00-06:00'
-            pivot = 166
-        # Since this is 2 tables, it gets returned as invalid json like "[{}][{}]"" instead of "[[{}],[{}]]"
-        # so we just do some hacky string substitution to pull out the respective arrays that can be jsonifyied
 
-        output_summary = json.loads(result.output[0:-pivot])
-        output_list = json.loads(result.output[-pivot:])
+        split_output = []
+        for table in utils.decode_stacked(result.output):
+            split_output.append(table)
+
+        self.assertEqual(len(split_output), 2)
+        output_summary = split_output[0]
+        output_list = split_output[1]
 
         self.assertEqual(output_summary[0]['Average MBps'], 0.3841)
         self.assertEqual(output_summary[1]['Max Date'], date)
@@ -692,19 +693,19 @@ class ServerCLITests(testing.TestCase):
                                            'getResourceRecords')
         getResourceRecords.return_value = []
         createAargs = ({
-                           'type': 'a',
-                           'host': 'hardware-test1',
-                           'domainId': 12345,  # from SoftLayer_Account::getDomains
-                           'data': '172.16.1.100',
-                           'ttl': 7200
-                       },)
+            'type': 'a',
+            'host': 'hardware-test1',
+            'domainId': 12345,  # from SoftLayer_Account::getDomains
+            'data': '172.16.1.100',
+            'ttl': 7200
+        },)
         createPTRargs = ({
-                             'type': 'ptr',
-                             'host': '100',
-                             'domainId': 123456,
-                             'data': 'hardware-test1.test.sftlyr.ws',
-                             'ttl': 7200
-                         },)
+            'type': 'ptr',
+            'host': '100',
+            'domainId': 123456,
+            'data': 'hardware-test1.test.sftlyr.ws',
+            'ttl': 7200
+        },)
 
         result = self.run_command(['hw', 'dns-sync', '1000'])
 
@@ -747,12 +748,12 @@ class ServerCLITests(testing.TestCase):
             }
         }
         createV6args = ({
-                            'type': 'aaaa',
-                            'host': 'hardware-test1',
-                            'domainId': 12345,  # from SoftLayer_Account::getDomains
-                            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
-                            'ttl': 7200
-                        },)
+            'type': 'aaaa',
+            'host': 'hardware-test1',
+            'domainId': 12345,  # from SoftLayer_Account::getDomains
+            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
+            'ttl': 7200
+        },)
         server.return_value = test_server
         result = self.run_command(['hw', 'dns-sync', '--aaaa-record', '1000'])
         self.assert_no_fail(result)
