@@ -360,13 +360,14 @@ class NetworkTests(testing.TestCase):
         self.assertEqual(result, fixtures.SoftLayer_Account.getNetworkVlans)
         _filter = {
             'networkVlans': {
-                'primaryRouter': {
-                    'datacenter': {
-                        'name': {'operation': '_= dal00'}},
-                },
+                'id': {
+                    'operation': 'orderBy',
+                    'options': [
+                           {'name': 'sort', 'value': ['ASC']}]},
                 'vlanNumber': {'operation': 5},
                 'name': {'operation': '_= primary-vlan'},
-            },
+                'primaryRouter': {
+                      'datacenter': {'name': {'operation': '_= dal00'}}}}
         }
         self.assert_called_with('SoftLayer_Account', 'getNetworkVlans',
                                 filter=_filter)
@@ -624,3 +625,15 @@ class NetworkTests(testing.TestCase):
 
         self.network.edit(vlan_id, name, note, tags)
         self.assert_called_with('SoftLayer_Network_Vlan', 'editObject')
+
+    def test_get_all_pods(self):
+        self.network.get_pods()
+        self.assert_called_with('SoftLayer_Network_Pod', 'getAllObjects')
+
+    def test_route(self):
+        self.network.route('SoftLayer_Hardware_Server', 123456, 100)
+        self.assert_called_with('SoftLayer_Network_Subnet', 'route')
+
+    def test_get_all_datacenter(self):
+        self.network.get_datacenter()
+        self.assert_called_with('SoftLayer_Location', 'getDatacenters')
